@@ -220,7 +220,7 @@ void ChatWindow::appendCommandMessage(const QString& command,const QString& mess
 void ChatWindow::appendBacklogMessage(const QString& firstColumn,const QString& message)
 {
     if(!textView) return ;
-    textView->appendBacklogMessage(firstColumn,message);
+    textView->appendBacklogMessage(firstColumn,Konversation::sterilizeUnicode(message));
 }
 
 void ChatWindow::cdIntoLogPath()
@@ -368,14 +368,7 @@ void ChatWindow::setLogfileName(const QString& name)
                 QStringList::Iterator itFirstColumn = firstColumns.begin();
                 QStringList::Iterator itMessage = messages.begin();
                 for( ; itFirstColumn != firstColumns.end() ; ++itFirstColumn, ++itMessage )
-                {
-                    // Qt uses 0xFDD0 and 0xFDD1 to mark the beginning and end of text frames. Remove
-                    // these here to avoid fatal errors encountered in QText* and the event loop pro-
-                    // cessing.
-                    itMessage->remove(QChar(0xFDD0)).remove(QChar(0xFDD1));
-
                     appendBacklogMessage(*itFirstColumn, *itMessage);
-                }
             }
         } // if(Preferences::showBacklog())
     }
