@@ -168,9 +168,7 @@ void ViewContainer::setupTabWidget()
 
     m_tabWidget->setTabReorderingEnabled(true);
     m_tabWidget->setTabCloseActivatePrevious(true);
-#if QT_VERSION >= 0x040500
     m_tabWidget->tabBar()->setSelectionBehaviorOnRemove(QTabBar::SelectPreviousTab);
-#endif
 
     m_vbox->hide();    //m_tabWidget->hide();
 
@@ -180,7 +178,7 @@ void ViewContainer::setupTabWidget()
     m_tabWidget->setCornerWidget(closeBtn, Qt::BottomRightCorner);
     connect(closeBtn, SIGNAL(clicked()), this, SLOT(closeCurrentView()));
 
-    connect(m_tabWidget, SIGNAL(currentChanged(int)), this, SLOT (switchView(int)));
+    connect(m_tabWidget, SIGNAL(currentChanged(int)), this, SLOT (viewSwitched(int)));
     connect(m_tabWidget, SIGNAL(closeRequest(QWidget*)), this, SLOT(closeView(QWidget*)));
     connect(m_tabWidget, SIGNAL(contextMenu(QWidget*, const QPoint&)), this, SLOT(showViewContextMenu(QWidget*, const QPoint&)));
     connect(m_tabWidget, SIGNAL(mouseMiddleClick(QWidget*)), this, SLOT(closeViewMiddleClick(QWidget*)));
@@ -396,10 +394,8 @@ void ViewContainer::updateTabWidgetAppearance()
     bool noTabBar = (Preferences::self()->tabPlacement()==Preferences::Left);
     m_tabWidget->setTabBarHidden(noTabBar);
 
-#if KDE_IS_VERSION(4, 2, 85)
-    m_tabWidget->setDocumentMode(noTabBar);
-#endif
-
+    m_tabWidget->setDocumentMode(true);
+    
     if (Preferences::self()->customTabFont())
         m_tabWidget->setFont(Preferences::self()->tabFont());
     else
@@ -413,8 +409,7 @@ void ViewContainer::updateTabWidgetAppearance()
     else
         m_tabWidget->cornerWidget()->hide();
 
-    //FIXME: Change to QTabBar::setTabsClosable() once we depend on Qt 4.5+
-    m_tabWidget->setCloseButtonEnabled(Preferences::self()->closeButtons());
+    m_tabWidget->tabBar()->setTabsClosable(Preferences::self()->closeButtons());
 
     m_tabWidget->setAutomaticResizeTabs(Preferences::self()->useMaxSizedTabs());
 }
@@ -691,6 +686,9 @@ void ViewContainer::updateViewActions(int index)
         action = actionCollection()->action("close_queries");
         if (action) action->setEnabled(false);
     }
+
+    action = actionCollection()->action("last_focused_tab");
+    if (action) action->setEnabled(m_lastFocusedView != 0);
 }
 
 void ViewContainer::updateFrontView()
@@ -1387,11 +1385,14 @@ void ViewContainer::addView(ChatWindow* view, const QString& label, bool weiniti
     updateViewActions(m_tabWidget->currentIndex());
 }
 
-void ViewContainer::switchView(int newIndex)
+void ViewContainer::viewSwitched(int newIndex)
 {
     ChatWindow* view = static_cast<ChatWindow*>(m_tabWidget->widget(newIndex));
     if (!view) return;
 
+    m_lastFocusedView = m_currentView;
+    m_currentView = view;
+
     emit viewChanged(view);
 
     if (m_frontView)
@@ -1476,6 +1477,32 @@ void ViewContainer::showPreviousView()
     goToView(m_tabWidget->currentIndex()-1);
 }
 
+void ViewContainer::showNextActiveView()
+{
+    if (!m_activeViewOrderList.isEmpty())
+    {
+        ChatWindow* prev = m_activeViewOrderList.first();
+        ChatWindow* view = prev;
+
+        QList<ChatWindow*>::ConstIterator it;
+
+        for (it = m_activeViewOrderList.constBegin(); it != m_activeViewOrderList.constEnd(); ++it)
+        {
+            if ((*it)->currentTabNotification() < prev->currentTabNotification())
+                view = (*it);
+        }
+
+        m_tabWidget->setCurrentIndex(m_tabWidget->indexOf(view));
+    }
+}
+
+void ViewContainer::showLastFocusedView()
+{
+    if (m_lastFocusedView)
+        showView(m_lastFocusedView);
+}
+
+
 void ViewContainer::moveViewLeft()
 {
     int index;
@@ -1567,6 +1594,12 @@ void ViewContainer::cleanupAfterClose(ChatWindow* view)
 {
     if (view == m_frontView) m_frontView = 0;
 
+    if (view == m_lastFocusedView)
+    {
+        QAction* action = actionCollection()->action("last_focused_tab");
+        if (action) action->setEnabled(false);
+    }
+
     if (m_tabWidget)
     {
         const int idx = m_tabWidget->indexOf(view);
@@ -1857,8 +1890,11 @@ void ViewContainer::clearAllViews()
     {
         nextPage=static_cast<ChatWindow*>(m_tabWidget->widget(i));
 
-        if(nextPage && nextPage->getTextView())
+        if (nextPage && nextPage->getTextView())
+        {
             nextPage->getTextView()->clear();
+            unsetViewNotification(nextPage);
+        }
     }
 }
 
@@ -2087,8 +2123,8 @@ void ViewContainer::addUrlCatcher()
         Application *konvApp=static_cast<Application *>(KApplication::kApplication());
         connect(konvApp,SIGNAL(catchUrl(const QString&,const QString&,const QDateTime&)),
             m_urlCatcherPanel, SLOT(addUrl(const QString&,const QString&,const QDateTime&)) );
-        connect(m_urlCatcherPanel, SIGNAL(deleteUrl(const QString&,const QString&)),
-            konvApp, SLOT(deleteUrl(const QString&,const QString&)) );
+        connect(m_urlCatcherPanel, SIGNAL(deleteUrl(const QString&,const QString&,const QDateTime&)),
+            konvApp, SLOT(deleteUrl(const QString&,const QString&,const QDateTime&)) );
         connect(m_urlCatcherPanel, SIGNAL(clearUrlList()),
             konvApp, SLOT(clearUrlList()));
 
@@ -2195,8 +2231,8 @@ StatusPanel* ViewContainer::addStatusView(Server* server)
     connect(statusView, SIGNAL(sendFile()), server, SLOT(requestDccSend()));
     connect(server, SIGNAL(awayState(bool)), statusView, SLOT(indicateAway(bool)) );
 
-    // make sure that m_frontServer gets set on adding the first status panel, too,
-    // since there won't be a switchView happening
+    // Make sure that m_frontServer gets set on adding the first status panel, too,
+    // since there won't be a viewSwitched happening.
     if (!m_frontServer) setFrontServer(server);
 
     return statusView;
@@ -2226,7 +2262,7 @@ void ViewContainer::reconnectFrontServer()
     else
         server = m_frontServer;
 
-    if (server) server->reconnect();
+    if (server) server->reconnectServer();
 }
 
 void ViewContainer::disconnectFrontServer()
@@ -2239,7 +2275,7 @@ void ViewContainer::disconnectFrontServer()
         server = m_frontServer;
 
     if (server && server->isConnected())
-        server->disconnect();
+        server->disconnectServer();
 }
 
 void ViewContainer::showJoinChannelDialog()
@@ -2515,25 +2551,6 @@ void ViewContainer::closeNicksOnlinePanel()
     (dynamic_cast<KToggleAction*>(actionCollection()->action("open_nicksonline_window")))->setChecked(false);
 }
 
-void ViewContainer::showNextActiveView()
-{
-    if (!m_activeViewOrderList.isEmpty())
-    {
-        ChatWindow* prev = m_activeViewOrderList.first();
-        ChatWindow* view = prev;
-
-        QList<ChatWindow*>::ConstIterator it;
-
-        for (it = m_activeViewOrderList.constBegin(); it != m_activeViewOrderList.constEnd(); ++it)
-        {
-            if ((*it)->currentTabNotification() < prev->currentTabNotification())
-                view = (*it);
-        }
-
-        m_tabWidget->setCurrentIndex(m_tabWidget->indexOf(view));
-    }
-}
-
 /*!
     \fn ViewContainer::frontServerChanging(Server *newServer)
 
